⚡ Day 8: 2.2x FASTER with rayon parallel sorting! From 33ms to 15ms 💪

This commit is contained in:
Russell Champoux committed 2025-12-09 16:04:45 -05:00
1 parent ca302578c9
commit 6ff1349679
4 files changed
+104 -28

No files matched your search

+1
View File
@@ -26,6 +26,7 @@ chrono = { version = "0.4.38", optional = true }
dhat = { version = "0.3.3", optional = true }
itertools = "0.14.0"
pico-args = "0.5.0"
rayon = "1.11.0"
tinyjson = "2.5.1"
# Solution dependencies